@@ -43,7 +43,7 @@ static void nextname();	/* Find next available name (namea, nameb, ...) */
 static int ExtractFITS();
 
 static int verbose = 0;		/* verbose/debugging flag */
-static char *RevMsg = "GETFITS WCSTools 3.9.4, 2 August 2016, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "GETFITS WCSTools 3.9.5, 30 March 2017, Jessica Mink (jmink@cfa.harvard.edu)";
 static int version = 0;		/* If 1, print only program name and version */
 static char outname[128];	/* Name for output image */
 static char outdir[256];	/* Output directory pathname */
