@@ -37,7 +37,7 @@
 static void usage();
 static int ExtractImage();
 
-static char *RevMsg = "IMEXTRACT WCSTools 3.9.4, 2 August 2016, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "IMEXTRACT WCSTools 3.9.5, 30 March 2017, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static int verbose = 0;		/* verbose flag */
 static int krename = 0;
