@@ -1274,9 +1274,16 @@ char	*numstr;	/* Formatted number (returned) */
 	}
 
 
-    /* Tycho or ACT catalogs */
-    else if (refcat==TYCHO || refcat==TYCHO2 ||
-	     refcat == TYCHO2E || refcat==ACT) {
+    /* Tycho2 */
+    else if (refcat==TYCHO2) {
+	if (nnfld < 0)
+	    sprintf (numstr, "%010.6f", dnum);
+	else
+	    sprintf (numstr, "%10.6f", dnum);
+	}
+
+    /* Other Tycho or ACT catalogs */
+    else if (refcat==TYCHO || refcat == TYCHO2E || refcat==ACT) {
 	if (nnfld < 0)
 	    sprintf (numstr, "%010.5f", dnum);
 	else
@@ -1396,9 +1403,12 @@ int	nndec;		/* Number of decimal places ( >= 0) */
     else if (refcat==SKY2K)
 	return (7);
 
+    /* Tycho2 catalog */
+    else if (refcat == TYCHO2)
+	return (11);
+
     /* Tycho, Tycho2, or ACT catalogs */
-    else if (refcat == TYCHO || refcat == TYCHO2 ||
-	     refcat == TYCHO2E || refcat == ACT)
+    else if (refcat == TYCHO || refcat == TYCHO2E || refcat == ACT)
 	return (10);
 
     /* Starbase tab-separated, TDC binary, or TDC ASCII catalogs */
