@@ -1,8 +1,8 @@
 /*** File libwcs/ucacread.c
- *** June 12, 2015
+ *** June 22, 2016
  *** By Jessica Mink, jmink@cfa.harvard.edu
  *** Harvard-Smithsonian Center for Astrophysics
- *** Copyright (C) 2003-2015
+ *** Copyright (C) 2003-2016
  *** Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 
  This library is free software; you can redistribute it and/or
@@ -822,7 +822,7 @@ ucacrnum (refcatname,nstars,sysout,eqout,epout,
         else if (ucat == UCAC2) {
           fprintf (stderr,"UCACRNUM: %11.6f: %9.5f %9.5f %5.2f",
                    num, ra, dec, star->xmag[0]);
-          fprintf (stderr," %5.2f %5.2f %5.2f %d %d",
+          fprintf (stderr," %5.2f %5.2f %5.2f",
                    star->xmag[1],star->xmag[2],star->xmag[3]);
           fprintf (stderr," %d %d\n",star->nimage,star->ncat);
 		    }
@@ -1928,4 +1928,6 @@ ucacswap4 (string)
  * Jan 29 2013  Add UCAC4 support see "DASCH" tag for DASCH-specific changes
  *
  * Jun 12 2015	Fix UCAC4 support to include BVgriJHK magnitudes correctly
+ *
+ * Jun 22 2016	Remove extra variables from format string (via Ole Streicher)
  */
