@@ -36,7 +36,7 @@ extern void setnpix();
 extern struct WorldCoor *GetFITSWCS ();	/* Read WCS from FITS or IRAF header */
 static int version = 0;		/* If 1, print only program name and version */
 
-static char *RevMsg = "SKY2XY WCSTools 3.9.4, 2 August 2016, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "SKY2XY WCSTools 3.9.5, 30 March 2017, Jessica Mink (jmink@cfa.harvard.edu)";
 
 int
 main (ac, av)
